<?php

/*****************************************************************************
 * 
 * サンプルのため、冗長なコメントになっています。
 * 
 ****************************************************************************/

/**
 * 送信テストを行う場合は、メールアドレスを設定してください。
 *
 *   サンプルのため、ここに定義していますが、本来このような定数は、
 *   Lambda/apps/<APP_DIR>/app.conf.php に定義することが推奨されます。
 */
define('MAILTO_ADMIN', '');

/**
 * リクエストが「http://example.com/mailform」のように、/ (スラッシュ)で
 * 終わっていない場合、/ (スラッシュ)付きURLにリダイレクトする。
 *
 *   ビュー(index.view.php)の <form action="" ... > にて、
 *   
 *     <form action="<?php echo APP_ROOT ?>/mailform/" ... >
 *   
 *   上記のように、モジュールグループを直接記述すれば、
 *   このステートメントは不要になります。
 *   ※ 本来は、上記のように直接記述することが推奨されます。
 *   
 *   本モジュールはサンプルのため、環境に依存した記述を減らし、
 *   設置の誤りを防ぐ意味で、下記のように <form action> の値を動的に
 *   生成している都合上、このようなリダイレクト処理が必要になっています。
 *   
 *   <form action="<?php echo $lmd->httpRequestDir() ?>/">
 */
if (substr($lmd->httpRequestUri(), -9) === '/mailform') {
    $lmd->redirect($lmd->httpRequestUri().'/');
    exit;
}

/**
 * POSTパラメーターを配列に格納。
 *
 *   こうしておくと、後続処理の setResponse や invokeValidator に値を渡す際に
 *   簡素に記述できます。
 */
$p = array(
    'name'    => $lmd->httpPost('name'),
    'email'   => $lmd->httpPost('email'),
    'os'      => $lmd->httpPost('os'),
    'within'  => $lmd->httpPost('within'),
    'browser' => $lmd->httpPost('browser', array()),
    'message' => $lmd->httpPost('message'),
);

/**
 * レスポンスをアサインしておく
 */
$lmd->setResponse($p);

if ($lmd->hasHttpPost('confirm') || $lmd->hasHttpPost('complete')) {
    /**
     * 【確認】または【送信】ボタンが押された。
     *
     *   バリデーターを実行して、入力値の検証を行います。
     *   ※ バリデーター定義は、Lambda/validators/mailform.php にあります。
     */
    $lmd->invokeValidator('mailform', $p);
}

if ($lmd->hasValidatorError()) {
    /**
     * 入力エラーが発見された。
     *
     *   ⇒ 「入力画面」に遷移させる。
     */
    return $lmd->setPrep('mailform.index');
}

if ($lmd->hasHttpPost('confirm') && ! $lmd->hasValidatorError()) {
    /**
     * 【確認】ボタンが押され、入力エラーが無い。
     *
     *   ⇒ 「確認画面」に遷移させる。
     */
    return $lmd->setPrep('mailform.confirm');
}

if ($lmd->hasHttpPost('complete') && ! $lmd->hasValidatorError()) {
    /**
     * 【送信】ボタンが押され、入力エラーが無い。
     *
     *   ⇒ メール送信を実行します。
     * 
     *   ※ テンプレートは、Lambda/mailtemplates/mailform.php にあります。
     */
    $to   = MAILTO_ADMIN;
    $from = $p['email'];
    Mail::setTemplate('mailform');
    Mail::setParams($p);
    if ($to) Mail::send($to, $from);

    /**
     * リロード操作での二重送信を防止するため、「完了画面」へはリダイレクトさせます。
     */
    $lmd->redirect($lmd->httpRequestDir().'/complete');
    exit;
}



/*****************************************************************************
 * ここまで来たら、暗黙のうちに mailform/index.prep.php に処理が移ります。
 * mailform/index.prep.php がない場合は、mailform/index.view.php に処理が移ります。
 */


